@@ -8,7 +8,6 @@
 
 #include "emailindexer.h"
 #include "akonadi_indexer_agent_email_debug.h"
-#include "stringutil.h"
 
 #include <Akonadi/Collection>
 #include <Akonadi/MessageFlags>
@@ -249,7 +248,7 @@ void EmailIndexer::processPart(KMime::Content *content, KMime::Content *mainCont
         // Only get HTML content, if no plain text content
         if (!mainContent && type->isHTMLText()) {
             QProcess converter;
-            converter.start(QStringLiteral("akonadi_html_to_text"), {});
+            converter.start(QStringLiteral("akonadi_html_to_text"));
             if (!converter.waitForStarted()) {
                 return;
             }
