@@ -20,6 +20,7 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QWindow>
+using namespace Qt::Literals::StringLiterals;
 
 using namespace Akonadi::Search;
 
@@ -49,7 +50,7 @@ AkonadiSearchDebugDialog::AkonadiSearchDebugDialog(QWidget *parent)
     connect(user1Button, &QPushButton::clicked, this, &AkonadiSearchDebugDialog::slotSaveAs);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AkonadiSearchDebugDialog::reject);
     d->mAkonadiSearchDebugWidget = new AkonadiSearchDebugWidget(this);
-    d->mAkonadiSearchDebugWidget->setObjectName(QLatin1StringView("akonadisearchdebugwidget"));
+    d->mAkonadiSearchDebugWidget->setObjectName("akonadisearchdebugwidget"_L1);
     mainLayout->addWidget(d->mAkonadiSearchDebugWidget);
     mainLayout->addWidget(buttonBox);
     readConfig();
@@ -65,14 +66,14 @@ void AkonadiSearchDebugDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(800, 600));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myAkonadiSearchDebugDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myAkonadiSearchDebugDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void AkonadiSearchDebugDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myAkonadiSearchDebugDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myAkonadiSearchDebugDialogConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
